netapp_ontap.models.svm_aggregates API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.svm_aggregates`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SvmAggregatesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SvmAggregates object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `available_size: Size GET`

    Space available, in bytes.

    Example: 10156560384

  `links: SelfLink GET`

    The links field of the svm_aggregates.

  `name: str GET POST PATCH`

    The name field of the svm_aggregates.

    Example: aggr1

  `snaplock_type: str GET`

    SnapLock type.

    Valid choices:

    - non_snaplock
    - compliance
    - enterprise
  `state: str GET`

    Aggregate state.

    Valid choices:

    - online
    - offline
    - unknown
  `type: str GET`

    Type of aggregate.

    Valid choices:

    - hdd
    - hybrid
    - lun
    - ssd
    - vmdisk
  `uuid: str GET POST PATCH`

    The uuid field of the svm_aggregates.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412